@@ -26,11 +26,6 @@ class DynamicTask():
             return
 
         try:
-            if not os.path.isfile(module_name.replace('.', '/') + '.py'):
-                log_debug(
-                    f'🟥 DynamicTask - module not found [{task_id}] specify "module.class" (lowercase)')
-                return
-
             module = importlib.import_module(module_name)
             class_ = getattr(module, class_name)
             self.instance = class_(payload)
